/*******************************************************************************
* File Name: RTC_Demo.h
* Version 1.60
*
* Description:
*  This file provides constants and parameter values for the RTC Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_RTC_RTC_Demo_H)
#define CY_RTC_RTC_Demo_H

#include "cytypes.h"
#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cyPm.h"


/***************************************
*   Conditional Compilation Parameters
***************************************/

/* PSoC3 ES2 or early */
#define RTC_Demo_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                     			      (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
                     
#if((RTC_Demo_PSOC3_ES2) && (RTC_Demo_isr__ES2_PATCH))
    #include <intrins.h>
    #define RTC_Demo_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
#endif  /* (RTC_Demo_PSOC3_ES2 && (RTC_Demo_isr__ES2_PATCH)) */

/* what day of the week is start of week */
#define RTC_Demo_START_OF_WEEK          (0u)

/* Daylight saving time */
#define RTC_Demo_DST_FUNC_ENABLE        (0u)


/***************************************
*    Data Struct Definitions
***************************************/

typedef struct _RTC_Demo_TIME_DATE
{
    uint8 Sec;
    uint8 Min;
    uint8 Hour;
    uint8 DayOfWeek;
    uint8 DayOfMonth;
    uint16 DayOfYear;
    uint8 Month;
    uint16 Year;
} volatile RTC_Demo_TIME_DATE;

typedef struct _RTC_Demo_DSTIME
{
    uint8 Hour;
    uint8 DayOfWeek;
    uint8 Week;
    uint8 DayOfMonth;
    uint8 Month;
} volatile RTC_Demo_DSTIME;


/***************************************
*    Function Prototypes
***************************************/

CY_ISR_PROTO(RTC_Demo_ISR);

void RTC_Demo_Start(void);
void RTC_Demo_Stop(void) ;
void RTC_Demo_EnableInt(void) ;
void RTC_Demo_DisableInt(void) ;
void  RTC_Demo_Init(void);
void RTC_Demo_Enable(void) ;

RTC_Demo_TIME_DATE* RTC_Demo_ReadTime(void) ;
void RTC_Demo_WriteTime(RTC_Demo_TIME_DATE *timeDate);

/* RTC write functions to set Start Values */
void RTC_Demo_WriteSecond(uint8 second);
void RTC_Demo_WriteMinute(uint8 minute);
void RTC_Demo_WriteHour(uint8 hour);
void RTC_Demo_WriteDayOfMonth(uint8 dayOfMonth);
void RTC_Demo_WriteMonth(uint8 month);
void RTC_Demo_WriteYear(uint16 year);

/* RTC Alarm write settings */
void RTC_Demo_WriteAlarmSecond(uint8 second);
void RTC_Demo_WriteAlarmMinute(uint8 minute);
void RTC_Demo_WriteAlarmHour(uint8 hour);
void RTC_Demo_WriteAlarmDayOfMonth(uint8 dayOfMonth);
void RTC_Demo_WriteAlarmMonth(uint8 month);
void RTC_Demo_WriteAlarmYear(uint16 year);
void RTC_Demo_WriteAlarmDayOfWeek(uint8 dayOfWeek);
void RTC_Demo_WriteAlarmDayOfYear(uint16 dayOfYear);

/* RTC read settings to set start values */
uint8 RTC_Demo_ReadSecond(void) ;
uint8 RTC_Demo_ReadMinute(void) ;
uint8 RTC_Demo_ReadHour(void) ;
uint8 RTC_Demo_ReadDayOfMonth(void) ;
uint8 RTC_Demo_ReadMonth(void) ;
uint16 RTC_Demo_ReadYear(void) ;

/* Alarm read settings */
uint8 RTC_Demo_ReadAlarmSecond(void) ;
uint8 RTC_Demo_ReadAlarmMinute(void) ;
uint8 RTC_Demo_ReadAlarmHour(void) ;
uint8 RTC_Demo_ReadAlarmDayOfMonth(void) ;
uint8 RTC_Demo_ReadAlarmMonth(void) ;
uint16 RTC_Demo_ReadAlarmYear(void) ;
uint8 RTC_Demo_ReadAlarmDayOfWeek(void) ;
uint16 RTC_Demo_ReadAlarmDayOfYear(void) ;

/* Set mask interrupt registers */
void RTC_Demo_WriteAlarmMask(uint8 mask);
void RTC_Demo_WriteIntervalMask(uint8 mask);

/* Read status register */
uint8 RTC_Demo_ReadStatus(void);

#if (1u == RTC_Demo_DST_FUNC_ENABLE)

    /* DST write settings  */
    void RTC_Demo_WriteDSTMode(uint8 mode);
    void RTC_Demo_WriteDSTStartHour(uint8 hour);
    void RTC_Demo_WriteDSTStartDayOfMonth(uint8 dayOfMonth);
    void RTC_Demo_WriteDSTStartMonth(uint8 month);
    void RTC_Demo_WriteDSTStartDayOfWeek(uint8 dayOfWeek);
    void RTC_Demo_WriteDSTStartWeek(uint8 week);

    void RTC_Demo_WriteDSTStopHour(uint8 hour);
    void RTC_Demo_WriteDSTStopDayOfMonth(uint8 dayOfMonth);
    void RTC_Demo_WriteDSTStopMonth(uint8 month);
    void RTC_Demo_WriteDSTStopDayOfWeek(uint8 dayOfWeek);
    void RTC_Demo_WriteDSTStopWeek(uint8 week);
    void RTC_Demo_WriteDSTOffset(uint8 offset);
    
#endif /* 1u == RTC_Demo_DST_FUNC_ENABLE */


/***************************************
*        API Constants
***************************************/

/* Number of the RTC_Demo_isr interrupt */
#define RTC_Demo_ISR_NUMBER             RTC_Demo_isr__INTC_NUMBER

/* Priority of the RTC_Demo_isr interrupt */
#define RTC_Demo_ISR_PRIORITY           RTC_Demo_isr__INTC_PRIOR_NUM

/* Time elapse constants */
#define RTC_Demo_MINUTE_ELAPSED         (59u)
#define RTC_Demo_HOUR_ELAPSED           (59u)
#define RTC_Demo_HALF_OF_DAY_ELAPSED    (12u)
#define RTC_Demo_DAY_ELAPSED            (23u)
#define RTC_Demo_WEEK_ELAPSED           (7u)
#define RTC_Demo_YEAR_ELAPSED           (12u)
#define RTC_Demo_DAYS_IN_WEEK           (7u)

/* Interval software register bit location */
#define RTC_Demo_INTERVAL_SEC_MASK      (0x01u)       /* SEC */
#define RTC_Demo_INTERVAL_MIN_MASK      (0x02u)       /* MIN */
#define RTC_Demo_INTERVAL_HOUR_MASK     (0x04u)       /* HOUR*/
#define RTC_Demo_INTERVAL_DAY_MASK      (0x08u)       /* DOM */
#define RTC_Demo_INTERVAL_WEEK_MASK     (0x10u)       /* DOM */
#define RTC_Demo_INTERVAL_MONTH_MASK    (0x20u)       /* MONTH */
#define RTC_Demo_INTERVAL_YEAR_MASK     (0x40u)       /* YEAR */

/* Alarm software register bit location */
#define RTC_Demo_ALARM_SEC_MASK         (0x01u)       /* SEC */
#define RTC_Demo_ALARM_MIN_MASK         (0x02u)       /* MIN */
#define RTC_Demo_ALARM_HOUR_MASK        (0x04u)       /* HOUR*/
#define RTC_Demo_ALARM_DAYOFWEEK_MASK   (0x08u)       /* DOW */
#define RTC_Demo_ALARM_DAYOFMONTH_MASK  (0x10u)       /* DOM */
#define RTC_Demo_ALARM_DAYOFYEAR_MASK   (0x20u)       /* DOY */
#define RTC_Demo_ALARM_MONTH_MASK       (0x40u)       /* MONTH */
#define RTC_Demo_ALARM_YEAR_MASK        (0x80u)       /* YEAR */

/* Status software register bit location */

/* DST stutus bit */
#define RTC_Demo_STATUS_DST             (0x01u)

/* Leap Year status bit */
#define RTC_Demo_STATUS_LY              (0x02u)

/* AM/PM status bit */
#define RTC_Demo_STATUS_AM_PM           (0x04u)

/* Alarm Active status bit */
#define RTC_Demo_STATUS_AA              (0x08u)

/* Days Of Week definition */
#define RTC_Demo_SUNDAY                       (1u)
#define RTC_Demo_MONDAY                       (2u)
#define RTC_Demo_TUESDAY                      (3u)
#define RTC_Demo_WEDNESDAY                    (4u)
#define RTC_Demo_THURDAY                      (5u)
#define RTC_Demo_FRIDAY                       (6u)
#define RTC_Demo_SATURDAY                     (7u)


/* Month definition */
#define RTC_Demo_JANUARY                (1u)
#define RTC_Demo_DAYS_IN_JANUARY        (31u)
#define RTC_Demo_FEBRUARY               (2u)
#define RTC_Demo_DAYS_IN_FEBRUARY       (28u)
#define RTC_Demo_MARCH                  (3u)
#define RTC_Demo_DAYS_IN_MARCH          (31u)
#define RTC_Demo_APRIL                  (4u)
#define RTC_Demo_DAYS_IN_APRIL          (30u)
#define RTC_Demo_MAY                    (5u)
#define RTC_Demo_DAYS_IN_MAY            (31u)
#define RTC_Demo_JUNE                   (6u)
#define RTC_Demo_DAYS_IN_JUNE           (30u)
#define RTC_Demo_JULY                   (7u)
#define RTC_Demo_DAYS_IN_JULY           (31u)
#define RTC_Demo_AUGUST                 (8u)
#define RTC_Demo_DAYS_IN_AUGUST         (31u)
#define RTC_Demo_SEPTEMBER              (9u)
#define RTC_Demo_DAYS_IN_SEPTEMBER      (30u)
#define RTC_Demo_OCTOBER                (10u)
#define RTC_Demo_DAYS_IN_OCTOBER        (31u)
#define RTC_Demo_NOVEMBER               (11u)
#define RTC_Demo_DAYS_IN_NOVEMBER       (30u)
#define RTC_Demo_DECEMBER               (12u)
#define RTC_Demo_DAYS_IN_DECEMBER       (31u)

/* DTS software registers bit location */

/* DST Enable */
#define RTC_Demo_DST_ENABLE             (0x01u)

/* Fixed data selected  */
#define RTC_Demo_DST_FIXDATE            (0x00u)

/* Relative data selected */
#define RTC_Demo_DST_RELDATE            (0x02u)

/* DST hour match flag */
#define RTC_Demo_DST_HOUR               (0x01u)

/* DST day of month match flag */
#define RTC_Demo_DST_DAYOFMONTH         (0x02u)

/* DST month match flag */
#define RTC_Demo_DST_MONTH              (0x04u)

#define RTC_Demo_MONTHS_IN_YEAR         (12u)
#define RTC_Demo_DAYS_IN_YEAR           (365u)
#define RTC_Demo_DAYS_IN_LEAP_YEAR      (366u)

/* Returns 1 if leap year, otherwise 0 */
#define RTC_Demo_LEAP_YEAR(year) ((!((year) % 400u) || (!((year) % 4u) && ((year) % 100u))) ? 0x01u : 0x00u)

/* Returns 1 if corresponding bit is set, otherwise 0 */
#define RTC_Demo_IS_BIT_SET(value, mask) (((mask) == ((value) & (mask))) ? 0x01u : 0x00u)

/* Set alarm if needed */
#define RTC_Demo_SET_ALARM(alarmCfg, alarmCur, status) \
    if((alarmCfg) && (RTC_Demo_IS_BIT_SET((alarmCur),(alarmCfg)))) \
    { \
        (status)  |= RTC_Demo_STATUS_AA; \
        (alarmCur) = 0u; \
    }

/* Following definitions are for the COMPATIBILITY ONLY, they are OBSOLETE. */
#define RTC_Demo_IsLeapYear         RTC_Demo_LEAP_YEAR
#define RTC_Demo_Dst                RTC_Demo_DSTIME
#define RTC_Demo_TimeDate           RTC_Demo_TIME_DATE

#define RTC_Demo_CurTimeDate        RTC_Demo_currentTimeDate
#define RTC_Demo_AlarmTimeDate      RTC_Demo_alarmCfgTimeDate

#if (1u == RTC_Demo_DST_FUNC_ENABLE)
    #define RTC_Demo_DstMode            RTC_Demo_dstModeType
    #define RTC_Demo_DstStartTimeDate   RTC_Demo_dstTimeDateStart
    #define RTC_Demo_DstStopTimeDate    RTC_Demo_dstTimeDateStop
    
    #define RTC_Demo_DstOffset          RTC_Demo_dstOffsetMin
    #define RTC_Demo_DstStatusStart     RTC_Demo_dstStartStatus
    #define RTC_Demo_DstStatusStop      RTC_Demo_dstStopStatus
#endif /* 1u == RTC_Demo_DST_FUNC_ENABLE */

#define RTC_Demo_AlarmMask      RTC_Demo_alarmCfgMask
#define RTC_Demo_AlarmStatus    RTC_Demo_alarmCurStatus
#define RTC_Demo_IntervalMask   RTC_Demo_intervalCfgMask
#define RTC_Demo_Status         RTC_Demo_statusDateTime
#define RTC_Demo_Dim            RTC_Demo_daysInMonths
#define RTC_Demo_Seq            RTC_Demo_monthTemplate


/***************************************
*    Registers
***************************************/

/* Timewheel Configuration Register 2 */
#define RTC_Demo_OPPS_CFG_REG           (* (reg8 *) CYREG_PM_TW_CFG2 )
#define RTC_Demo_OPPS_CFG_PTR           (  (reg8 *) CYREG_PM_TW_CFG2 )

/* Power Manager Interrupt Status Register */
#define RTC_Demo_OPPS_INT_SR_REG        (* (reg8 *) CYREG_PM_INT_SR )
#define RTC_Demo_OPPS_INT_SR_PTR        (  (reg8 *) CYREG_PM_INT_SR )


/***************************************
*    External Software Registers
***************************************/

extern RTC_Demo_TIME_DATE    RTC_Demo_alarmCfgTimeDate;
extern RTC_Demo_TIME_DATE    RTC_Demo_currentTimeDate;

#if (1u == RTC_Demo_DST_FUNC_ENABLE)
    extern volatile uint8             RTC_Demo_dstModeType;
    extern RTC_Demo_DSTIME     RTC_Demo_dstTimeDateStart;
    extern RTC_Demo_DSTIME     RTC_Demo_dstTimeDateStop;
    extern volatile uint8   RTC_Demo_dstOffsetMin;
    extern volatile uint8   RTC_Demo_dstStartStatus;
    extern volatile uint8   RTC_Demo_dstStopStatus;
#endif /* 1u == RTC_Demo_DST_FUNC_ENABLE */

extern volatile uint8       RTC_Demo_alarmCfgMask;
extern volatile uint8       RTC_Demo_alarmCurStatus;
extern volatile uint8       RTC_Demo_intervalCfgMask;
extern volatile uint8       RTC_Demo_statusDateTime;

extern const uint8 CYCODE   RTC_Demo_daysInMonths [RTC_Demo_MONTHS_IN_YEAR];
extern const uint8 CYCODE   RTC_Demo_monthTemplate [RTC_Demo_MONTHS_IN_YEAR];

    
/***************************************
*        Register Constants
****************************************/

#define RTC_Demo_OPPS_EN_MASK           (0x10u)
#define RTC_Demo_OPPSIE_EN_MASK         (0x20u)

/* Enable wakeup from the Sleeep low power mode */
#define RTC_Demo_PM_WAKEUP_CTW_1PPS     (0x80u)

#endif /* CY_RTC_RTC_Demo_H */


/* [] END OF FILE */
