/*******************************************************************************
* File Name: scl.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "scl.h"


/*******************************************************************************
* Function Name: scl_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void scl_Write(uint8 value) 
{
    uint8 staticBits = scl_DR & ~scl_MASK;
    scl_DR = staticBits | ((value << scl_SHIFT) & scl_MASK);
}


/*******************************************************************************
* Function Name: scl_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void scl_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(scl_0, mode);
}


/*******************************************************************************
* Function Name: scl_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro scl_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 scl_Read(void) 
{
    return (scl_PS & scl_MASK) >> scl_SHIFT;
}


/*******************************************************************************
* Function Name: scl_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 scl_ReadDataReg(void) 
{
    return (scl_DR & scl_MASK) >> scl_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(scl_INTSTAT) 

    /*******************************************************************************
    * Function Name: scl_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 scl_ClearInterrupt(void) 
    {
        return (scl_INTSTAT & scl_MASK) >> scl_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
